import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ConfigConfigurationAggregatorConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator.html#name ConfigConfigurationAggregator#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator.html#tags ConfigConfigurationAggregator#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator.html#tags_all ConfigConfigurationAggregator#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * account_aggregation_source block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator.html#account_aggregation_source ConfigConfigurationAggregator#account_aggregation_source}
     *
     * @stability stable
     */
    readonly accountAggregationSource?: ConfigConfigurationAggregatorAccountAggregationSource[];
    /**
     * organization_aggregation_source block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator.html#organization_aggregation_source ConfigConfigurationAggregator#organization_aggregation_source}
     *
     * @stability stable
     */
    readonly organizationAggregationSource?: ConfigConfigurationAggregatorOrganizationAggregationSource[];
}
/**
 * @stability stable
 */
export interface ConfigConfigurationAggregatorAccountAggregationSource {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator.html#account_ids ConfigConfigurationAggregator#account_ids}.
     *
     * @stability stable
     */
    readonly accountIds: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator.html#all_regions ConfigConfigurationAggregator#all_regions}.
     *
     * @stability stable
     */
    readonly allRegions?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator.html#regions ConfigConfigurationAggregator#regions}.
     *
     * @stability stable
     */
    readonly regions?: string[];
}
/**
 * @stability stable
 */
export interface ConfigConfigurationAggregatorOrganizationAggregationSource {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator.html#all_regions ConfigConfigurationAggregator#all_regions}.
     *
     * @stability stable
     */
    readonly allRegions?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator.html#regions ConfigConfigurationAggregator#regions}.
     *
     * @stability stable
     */
    readonly regions?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator.html#role_arn ConfigConfigurationAggregator#role_arn}.
     *
     * @stability stable
     */
    readonly roleArn: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator.html aws_config_configuration_aggregator}.
 *
 * @stability stable
 */
export declare class ConfigConfigurationAggregator extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator.html aws_config_configuration_aggregator} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ConfigConfigurationAggregatorConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _accountAggregationSource?;
    /**
     * @stability stable
     */
    get accountAggregationSource(): ConfigConfigurationAggregatorAccountAggregationSource[];
    /**
     * @stability stable
     */
    set accountAggregationSource(value: ConfigConfigurationAggregatorAccountAggregationSource[]);
    /**
     * @stability stable
     */
    resetAccountAggregationSource(): void;
    /**
     * @stability stable
     */
    get accountAggregationSourceInput(): ConfigConfigurationAggregatorAccountAggregationSource[] | undefined;
    private _organizationAggregationSource?;
    /**
     * @stability stable
     */
    get organizationAggregationSource(): ConfigConfigurationAggregatorOrganizationAggregationSource[];
    /**
     * @stability stable
     */
    set organizationAggregationSource(value: ConfigConfigurationAggregatorOrganizationAggregationSource[]);
    /**
     * @stability stable
     */
    resetOrganizationAggregationSource(): void;
    /**
     * @stability stable
     */
    get organizationAggregationSourceInput(): ConfigConfigurationAggregatorOrganizationAggregationSource[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
